@@ -8,7 +8,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.coretemp.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -20,7 +20,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @author    William Johansson <radar@radhuset.org>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -41,30 +41,30 @@ class Coretemp extends Sensors
                    $tempsensor = glob($hwpaths[$h]."temp*_input", GLOB_NOSORT);
                    if (($total = count($tempsensor)) > 0) {
                         $buf = "";
-                        for ($i = 0; $i < $total; $i++) if (CommonFunctions::rfts($tempsensor[$i], $buf, 1, 4096, false) && (trim($buf) != "")) {
+                        for ($i = 0; $i < $total; $i++) if (CommonFunctions::rfts($tempsensor[$i], $buf, 1, 4096, false) && (($buf = trim($buf)) != "")) {
                             $dev = new SensorDevice();
-                            $dev->setValue(trim($buf)/1000);
+                            $dev->setValue($buf/1000);
                             $label = preg_replace("/_input$/", "_label", $tempsensor[$i]);
                             $crit = preg_replace("/_input$/", "_crit", $tempsensor[$i]);
                             $max = preg_replace("/_input$/", "_max", $tempsensor[$i]);
                             $crit_alarm = preg_replace("/_input$/", "_crit_alarm", $tempsensor[$i]);
-                            if (CommonFunctions::fileexists($label) && CommonFunctions::rfts($label, $buf, 1, 4096, false) && (trim($buf) != "")) {
-                                $dev->setName(trim($buf));
+                            if (CommonFunctions::fileexists($label) && CommonFunctions::rfts($label, $buf, 1, 4096, false) && (($buf = trim($buf)) != "")) {
+                                $dev->setName($buf);
                             } else {
-                                $labelname = trim(preg_replace("/_input$/", "",  pathinfo($tempsensor[$i], PATHINFO_BASENAME)));
+                                $labelname = trim(preg_replace("/_input$/", "", pathinfo($tempsensor[$i], PATHINFO_BASENAME)));
                                 if ($labelname !== "") {
                                     $dev->setName($labelname);
                                 } else {
                                     $dev->setName('unknown');
                                 }
                             }
-                            if (CommonFunctions::fileexists($crit) && CommonFunctions::rfts($crit, $buf, 1, 4096, false) && (trim($buf) != "")) {
-                                $dev->setMax(trim($buf)/1000);
+                            if (CommonFunctions::fileexists($crit) && CommonFunctions::rfts($crit, $buf, 1, 4096, false) && (($buf = trim($buf)) != "")) {
+                                $dev->setMax($buf/1000);
                                 if (CommonFunctions::fileexists($crit_alarm) && CommonFunctions::rfts($crit_alarm, $buf, 1, 4096, false) && (trim($buf) === "1")) {
                                     $dev->setEvent("Critical Alarm");
                                 }
-                            } elseif (CommonFunctions::fileexists($max) && CommonFunctions::rfts($max, $buf, 1, 4096, false) && (trim($buf) != "")) {
-                                $dev->setMax(trim($buf)/1000);
+                            } elseif (CommonFunctions::fileexists($max) && CommonFunctions::rfts($max, $buf, 1, 4096, false) && (($buf = trim($buf)) != "")) {
+                                $dev->setMax($buf/1000);
                             }
                             $this->mbinfo->setMbTemp($dev);
                         }
