@@ -8,7 +8,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.freeipmi.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -19,7 +19,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -152,6 +152,7 @@ class FreeIPMI extends Sensors
                 $dev = new SensorDevice();
                 $dev->setName($buffer[1]);
                 $dev->setValue($buffer[3]);
+                if ($buffer[6] != "N/A") $dev->setMin($buffer[6]);
                 if ($buffer[9] != "N/A") $dev->setMax($buffer[9]);
                 if ($buffer[11] != "'OK'") $dev->setEvent(trim($buffer[11], "'"));
                 $this->mbinfo->setMbCurrent($dev);
@@ -159,6 +160,25 @@ class FreeIPMI extends Sensors
         }
     }
 
+    /**
+     * get other information
+     *
+     * @return void
+     */
+    private function _other()
+    {
+        foreach ($this->_lines as $line) {
+            $buffer = preg_split("/\s*\|\s*/", $line);
+             if ($buffer[4] == "N/A"
+                && $buffer[11] != "N/A") {
+                $dev = new SensorDevice();
+                $dev->setName($buffer[1].' ('.$buffer[2].')');
+                $dev->setValue(trim($buffer[11], '\''));
+                $this->mbinfo->setMbOther($dev);
+            }
+        }
+    }
+
     /**
      * get the information
      *
@@ -173,5 +193,6 @@ class FreeIPMI extends Sensors
         $this->_fans();
         $this->_power();
         $this->_current();
+        $this->_other();
     }
 }
