@@ -8,7 +8,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.ipmiutil.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -19,7 +19,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -63,7 +63,10 @@ class IPMIutil extends Sensors
     {
         foreach ($this->_lines as $line) {
             $buffer = preg_split("/\s*\|\s*/", $line);
-            if (isset($buffer[2]) && $buffer[2] == "Temperature" && $buffer[1] == "Full" && isset($buffer[6]) && preg_match("/^(\S+)\sC$/", $buffer[6], $value)) {
+            if (isset($buffer[2]) && $buffer[2] == "Temperature"
+               && $buffer[1] == "Full"
+               && isset($buffer[6]) && preg_match("/^(\S+)\sC$/", $buffer[6], $value)
+               && $buffer[5] !== "Init") {
                 $dev = new SensorDevice();
                 $dev->setName($buffer[4]);
                 $dev->setValue($value[1]);
@@ -90,7 +93,10 @@ class IPMIutil extends Sensors
     {
         foreach ($this->_lines as $line) {
             $buffer = preg_split("/\s*\|\s*/", $line);
-            if (isset($buffer[2]) && $buffer[2] == "Voltage" && $buffer[1] == "Full" && isset($buffer[6]) && preg_match("/^(\S+)\sV$/", $buffer[6], $value)) {
+            if (isset($buffer[2]) && $buffer[2] == "Voltage"
+               && $buffer[1] == "Full"
+               && isset($buffer[6]) && preg_match("/^(\S+)\sV$/", $buffer[6], $value)
+               && $buffer[5] !== "Init") {
                 $dev = new SensorDevice();
                 $dev->setName($buffer[4]);
                 $dev->setValue($value[1]);
@@ -123,7 +129,10 @@ class IPMIutil extends Sensors
     {
         foreach ($this->_lines as $line) {
             $buffer = preg_split("/\s*\|\s*/", $line);
-            if (isset($buffer[2]) && $buffer[2] == "Fan" && $buffer[1] == "Full" && isset($buffer[6]) && preg_match("/^(\S+)\sRPM$/", $buffer[6], $value)) {
+            if (isset($buffer[2]) && $buffer[2] == "Fan"
+               && $buffer[1] == "Full"
+               && isset($buffer[6]) && preg_match("/^(\S+)\sRPM$/", $buffer[6], $value)
+               && $buffer[5] !== "Init") {
                 $dev = new SensorDevice();
                 $dev->setName($buffer[4]);
                 $dev->setValue($value[1]);
@@ -157,7 +166,10 @@ class IPMIutil extends Sensors
     {
         foreach ($this->_lines as $line) {
             $buffer = preg_split("/\s*\|\s*/", $line);
-            if (isset($buffer[2]) && $buffer[2] == "Current" && $buffer[1] == "Full" && isset($buffer[6]) && preg_match("/^(\S+)\sW$/", $buffer[6], $value)) {
+            if (isset($buffer[2]) && $buffer[2] == "Current"
+               && $buffer[1] == "Full"
+               && isset($buffer[6]) && preg_match("/^(\S+)\sW$/", $buffer[6], $value)
+               && $buffer[5] !== "Init") {
                 $dev = new SensorDevice();
                 $dev->setName($buffer[4]);
                 $dev->setValue($value[1]);
@@ -184,11 +196,20 @@ class IPMIutil extends Sensors
     {
         foreach ($this->_lines as $line) {
             $buffer = preg_split("/\s*\|\s*/", $line);
-            if (isset($buffer[2]) && $buffer[2] == "Current" && $buffer[1] == "Full" && isset($buffer[6]) && preg_match("/^(\S+)\sA$/", $buffer[6], $value)) {
+            if (isset($buffer[2]) && $buffer[2] == "Current"
+               && $buffer[1] == "Full"
+               && isset($buffer[6]) && preg_match("/^(\S+)\sA$/", $buffer[6], $value)
+               && $buffer[5] !== "Init") {
                 $dev = new SensorDevice();
                 $dev->setName($buffer[4]);
                 $dev->setValue($value[1]);
                 if (isset($buffer[7]) && $buffer[7] == "Thresholds") {
+                    if ((isset($buffer[8]) && preg_match("/^lo-crit\s(\S+)\s*$/", $buffer[8], $limits))
+                        ||(isset($buffer[9]) && preg_match("/^lo-crit\s(\S+)\s*$/", $buffer[9], $limits))
+                        ||(isset($buffer[10]) && preg_match("/^lo-crit\s(\S+)\s*$/", $buffer[10], $limits))
+                        ||(isset($buffer[11]) && preg_match("/^lo-crit\s(\S+)\s*$/", $buffer[11], $limits))) {
+                        $dev->setMin($limits[1]);
+                    }
                     if ((isset($buffer[8]) && preg_match("/^hi-crit\s(\S+)\s*$/", $buffer[8], $limits))
                         ||(isset($buffer[9]) && preg_match("/^hi-crit\s(\S+)\s*$/", $buffer[9], $limits))
                         ||(isset($buffer[10]) && preg_match("/^hi-crit\s(\S+)\s*$/", $buffer[10], $limits))
@@ -202,6 +223,40 @@ class IPMIutil extends Sensors
         }
     }
 
+    /**
+     * get other information
+     *
+     * @return void
+     */
+    private function _other()
+    {
+        foreach ($this->_lines as $line) {
+            $buffer = preg_split("/\s*\|\s*/", $line);
+            if (isset($buffer[1]) && $buffer[1] == "Compact"
+               && $buffer[5] !== "Init"
+               && $buffer[5] !== "Unknown"
+               && $buffer[5] !== "NotAvailable") {
+                $dev = new SensorDevice();
+                $dev->setName($buffer[4].' ('.$buffer[2].')');
+
+                $buffer5s = preg_split("/\s+/", $buffer5 = $buffer[5]);
+                if (isset($buffer5s[1])) {
+                    $value = hexdec($buffer5s[0]) & 0xff;
+                    if ($buffer5s[1] === 'DiscreteEvt') {
+                        $dev->setValue('0x'.dechex($value));
+                    } elseif (($buffer5s[1] === 'DiscreteUnit') && ($value > 0)) {
+                        $dev->setValue('0x'.dechex($value - 1));
+                    } else {
+                        $dev->setValue($buffer5);
+                    }
+                } else {
+                    $dev->setValue($buffer5);
+                }
+                $this->mbinfo->setMbOther($dev);
+            }
+        }
+    }
+
     /**
      * get the information
      *
@@ -216,5 +271,6 @@ class IPMIutil extends Sensors
         $this->_fans();
         $this->_power();
         $this->_current();
+        $this->_other();
     }
 }
