@@ -8,7 +8,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.ohm.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -19,7 +19,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -39,24 +39,20 @@ class OHM extends Sensors
     {
         parent::__construct();
         $_wmi = null;
-        // don't set this params for local connection, it will not work
-        $strHostname = '';
-        $strUser = '';
-        $strPassword = '';
         try {
             // initialize the wmi object
             $objLocator = new COM('WbemScripting.SWbemLocator');
-            if ($strHostname == "") {
-                $_wmi = $objLocator->ConnectServer($strHostname, 'root\OpenHardwareMonitor');
-
-            } else {
-                $_wmi = $objLocator->ConnectServer($strHostname, 'root\OpenHardwareMonitor', $strHostname.'\\'.$strUser, $strPassword);
-            }
+            $_wmi = $objLocator->ConnectServer('', 'root\OpenHardwareMonitor');
         } catch (Exception $e) {
             $this->error->addError("WMI connect error", "PhpSysInfo can not connect to the WMI interface for OpenHardwareMonitor data.");
         }
         if ($_wmi) {
-            $this->_buf = CommonFunctions::getWMI($_wmi, 'Sensor', array('Parent', 'Name', 'SensorType', 'Value'));
+            $tmpbuf = CommonFunctions::getWMI($_wmi, 'Sensor', array('Parent', 'Name', 'SensorType', 'Value'));
+            if ($tmpbuf) foreach ($tmpbuf as $buffer) {
+                if (!isset($this->_buf[$buffer['SensorType']]) || !isset($this->_buf[$buffer['SensorType']][$buffer['Parent'].' '.$buffer['Name']])) { // avoid duplicates
+                    $this->_buf[$buffer['SensorType']][$buffer['Parent'].' '.$buffer['Name']] = $buffer['Value'];
+                }
+            }
         }
     }
 
@@ -67,13 +63,11 @@ class OHM extends Sensors
      */
     private function _temperature()
     {
-        if ($this->_buf) foreach ($this->_buf as $buffer) {
-            if ($buffer['SensorType'] == "Temperature") {
-                $dev = new SensorDevice();
-                $dev->setName($buffer['Parent'].' '.$buffer['Name']);
-                $dev->setValue($buffer['Value']);
-                $this->mbinfo->setMbTemp($dev);
-            }
+        if (isset($this->_buf['Temperature'])) foreach ($this->_buf['Temperature'] as $name=>$value) {
+            $dev = new SensorDevice();
+            $dev->setName($name);
+            $dev->setValue($value);
+            $this->mbinfo->setMbTemp($dev);
         }
     }
 
@@ -84,13 +78,11 @@ class OHM extends Sensors
      */
     private function _voltage()
     {
-        if ($this->_buf) foreach ($this->_buf as $buffer) {
-            if ($buffer['SensorType'] == "Voltage") {
-                $dev = new SensorDevice();
-                $dev->setName($buffer['Parent'].' '.$buffer['Name']);
-                $dev->setValue($buffer['Value']);
-                $this->mbinfo->setMbVolt($dev);
-            }
+        if (isset($this->_buf['Voltage'])) foreach ($this->_buf['Voltage'] as $name=>$value) {
+            $dev = new SensorDevice();
+            $dev->setName($name);
+            $dev->setValue($value);
+            $this->mbinfo->setMbVolt($dev);
         }
     }
 
@@ -101,13 +93,11 @@ class OHM extends Sensors
      */
     private function _fans()
     {
-        if ($this->_buf) foreach ($this->_buf as $buffer) {
-            if ($buffer['SensorType'] == "Fan") {
-                $dev = new SensorDevice();
-                $dev->setName($buffer['Parent'].' '.$buffer['Name']);
-                $dev->setValue($buffer['Value']);
-                $this->mbinfo->setMbFan($dev);
-            }
+        if (isset($this->_buf['Fan'])) foreach ($this->_buf['Fan'] as $name=>$value) {
+            $dev = new SensorDevice();
+            $dev->setName($name);
+            $dev->setValue($value);
+            $this->mbinfo->setMbFan($dev);
         }
     }
 
@@ -118,13 +108,11 @@ class OHM extends Sensors
      */
     private function _power()
     {
-        if ($this->_buf) foreach ($this->_buf as $buffer) {
-            if ($buffer['SensorType'] == "Power") {
-                $dev = new SensorDevice();
-                $dev->setName($buffer['Parent'].' '.$buffer['Name']);
-                $dev->setValue($buffer['Value']);
-                $this->mbinfo->setMbPower($dev);
-            }
+        if (isset($this->_buf['Power'])) foreach ($this->_buf['Power'] as $name=>$value) {
+            $dev = new SensorDevice();
+            $dev->setName($name);
+            $dev->setValue($value);
+            $this->mbinfo->setMbPower($dev);
         }
     }
 
