@@ -7,6 +7,7 @@
  * @category  PHP
  * @package   PSI_Sensor
  * @author    Marc Hillesheim <hawkeyexp@gmail.com>
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @copyright 2012 Marc Hillesheim
  * @link      http://pi.no-ip.biz
  */
@@ -16,15 +17,15 @@ class PiTemp extends Sensors
     {
         $temp = null;
         $temp_max = null;
-        if (!CommonFunctions::rfts('/sys/devices/platform/sunxi-i2c.0/i2c-0/0-0034/temp1_input', $temp, 0, 4096, false)) { // Not Banana Pi
-            CommonFunctions::rfts('/sys/class/thermal/thermal_zone0/temp', $temp);
-            CommonFunctions::rfts('/sys/class/thermal/thermal_zone0/trip_point_0_temp', $temp_max, 0, 4096, PSI_DEBUG);
+        if (!CommonFunctions::rfts('/sys/devices/platform/sunxi-i2c.0/i2c-0/0-0034/temp1_input', $temp, 1, 4096, false)) { // Not Banana Pi
+            CommonFunctions::rfts('/sys/class/thermal/thermal_zone0/temp', $temp, 1);
+            CommonFunctions::rfts('/sys/class/thermal/thermal_zone0/trip_point_0_temp', $temp_max, 1, 4096, PSI_DEBUG);
         }
-        if (!is_null($temp) && (trim($temp) != "")) {
+        if (!is_null($temp) && (($temp = trim($temp)) != "")) {
             $dev = new SensorDevice();
             $dev->setName("CPU 1");
             $dev->setValue($temp / 1000);
-            if (!is_null($temp_max) && (trim($temp_max) != "") && ($temp_max > 0)) {
+            if (!is_null($temp_max) && (($temp_max = trim($temp_max)) != "") && ($temp_max > 0)) {
                 $dev->setMax($temp_max / 1000);
             }
             $this->mbinfo->setMbTemp($dev);
@@ -34,7 +35,7 @@ class PiTemp extends Sensors
     private function _voltage()
     {
         $volt = null;
-        if (CommonFunctions::rfts('/sys/devices/platform/sunxi-i2c.0/i2c-0/0-0034/axp20-supplyer.28/power_supply/ac/voltage_now', $volt, 0, 4096, false) && !is_null($volt) && (trim($volt) != "")) { // Banana Pi
+        if (CommonFunctions::rfts('/sys/devices/platform/sunxi-i2c.0/i2c-0/0-0034/axp20-supplyer.28/power_supply/ac/voltage_now', $volt, 1, 4096, false) && !is_null($volt) && (($volt = trim($volt)) != "")) { // Banana Pi
             $dev = new SensorDevice();
             $dev->setName("Voltage 1");
             $dev->setValue($volt / 1000000);
@@ -45,7 +46,7 @@ class PiTemp extends Sensors
     private function _current()
     {
         $current = null;
-        if (CommonFunctions::rfts('/sys/devices/platform/sunxi-i2c.0/i2c-0/0-0034/axp20-supplyer.28/power_supply/ac/current_now', $current, 0, 4096, false) && !is_null($current) && (trim($current) != "")) { // Banana Pi
+        if (CommonFunctions::rfts('/sys/devices/platform/sunxi-i2c.0/i2c-0/0-0034/axp20-supplyer.28/power_supply/ac/current_now', $current, 1, 4096, false) && !is_null($current) && (($current = trim($current)) != "")) { // Banana Pi
             $dev = new SensorDevice();
             $dev->setName("Current 1");
             $dev->setValue($current / 1000000);
