@@ -8,7 +8,7 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.ohm.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -19,13 +19,13 @@
  * @package   PSI_Sensor
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
 class ThermalZone extends Sensors
 {
-/**
+    /**
      * holds the COM object that we pull all the WMI data from
      *
      * @var Object
@@ -40,19 +40,10 @@ class ThermalZone extends Sensors
         parent::__construct();
         if (PSI_OS == 'WINNT') {
             $_wmi = null;
-            // don't set this params for local connection, it will not work
-            $strHostname = '';
-            $strUser = '';
-            $strPassword = '';
             try {
                 // initialize the wmi object
                 $objLocator = new COM('WbemScripting.SWbemLocator');
-                if ($strHostname == "") {
-                    $_wmi = $objLocator->ConnectServer($strHostname, 'root\WMI');
-
-                } else {
-                    $_wmi = $objLocator->ConnectServer($strHostname, 'root\WMI', $strHostname.'\\'.$strUser, $strPassword);
-                }
+                $_wmi = $objLocator->ConnectServer('', 'root\WMI');
             } catch (Exception $e) {
                 $this->error->addError("WMI connect error", "PhpSysInfo can not connect to the WMI interface for ThermalZone data.");
             }
@@ -90,9 +81,11 @@ class ThermalZone extends Sensors
             foreach (glob('/sys/class/thermal/thermal_zone*/') as $thermalzone) {
                 $thermalzonetemp = $thermalzone.'temp';
                 $temp = null;
-                if (CommonFunctions::rfts($thermalzonetemp, $temp, 0, 4096, false) && !is_null($temp) && (trim($temp) != "")) {
+                if (CommonFunctions::rfts($thermalzonetemp, $temp, 1, 4096, false) && !is_null($temp) && (($temp = trim($temp)) != "")) {
                     if ($temp >= 1000) {
                         $temp = $temp / 1000;
+                    } elseif ($temp >= 200) {
+                        $temp = $temp / 10;
                     }
 
                     if ($temp > -40) {
@@ -100,16 +93,18 @@ class ThermalZone extends Sensors
                         $dev->setValue($temp);
 
                         $temp_type = null;
-                        if (CommonFunctions::rfts($thermalzone.'type', $temp_type, 0, 4096, false) && !is_null($temp_type) && (trim($temp_type) != "")) {
+                        if (CommonFunctions::rfts($thermalzone.'type', $temp_type, 1, 4096, false) && !is_null($temp_type) && (($temp_type = trim($temp_type)) != "")) {
                             $dev->setName($temp_type);
                         } else {
                             $dev->setName("ThermalZone");
                         }
 
                         $temp_max = null;
-                        if (CommonFunctions::rfts($thermalzone.'trip_point_0_temp', $temp_max, 0, 4096, false) && !is_null($temp_max) && (trim($temp_max) != "") && ($temp_max > 0)) {
+                        if (CommonFunctions::rfts($thermalzone.'trip_point_0_temp', $temp_max, 1, 4096, false) && !is_null($temp_max) && (($temp_max = trim($temp_max)) != "") && ($temp_max > -40)) {
                             if ($temp_max >= 1000) {
                                 $temp_max = $temp_max / 1000;
+                            } elseif ($temp_max >= 200) {
+                                $temp_max = $temp_max / 10;
                             }
                             $dev->setMax($temp_max);
                         }
@@ -122,7 +117,7 @@ class ThermalZone extends Sensors
             if ($notwas) {
                 foreach (glob('/proc/acpi/thermal_zone/TH*/temperature') as $thermalzone) {
                     $temp = null;
-                    if (CommonFunctions::rfts($thermalzone, $temp, 1, 4096, false) && !is_null($temp) && (trim($temp) != "")) {
+                    if (CommonFunctions::rfts($thermalzone, $temp, 1, 4096, false) && !is_null($temp) && (($temp = trim($temp)) != "")) {
                         $dev = new SensorDevice();
                         if (preg_match("/^\/proc\/acpi\/thermal_zone\/(.+)\/temperature$/", $thermalzone, $name)) {
                            $dev->setName("ThermalZone ".$name[1]);
