@@ -8,7 +8,7 @@
  * @package   PSI OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.OS.inc.php 699 2012-09-15 11:57:13Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -19,7 +19,7 @@
  * @package   PSI OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -28,7 +28,7 @@ abstract class OS implements PSI_Interface_OS
     /**
      * object for error handling
      *
-     * @var Error
+     * @var PSI_Error
      */
     protected $error;
 
@@ -142,7 +142,9 @@ abstract class OS implements PSI_Interface_OS
     final public function getSys()
     {
         $this->build();
-        $this->_ip();
+        if (!defined('PSI_ONLY') || PSI_ONLY==='vitals') {
+            $this->_ip();
+        }
 
         return $this->sys;
     }
