@@ -1,5 +1,21 @@
 function renderPlugin_dmraid(data) {
 
+    function raid_buildaction(data) {
+        var html = "", name = "", percent = 0;
+        if (data !== undefined) {
+            name = data['Name'];
+            if ((name !== undefined) && (parseInt(name) !== -1)) {
+                percent = Math.round(parseFloat(data['Percent']));
+                html += "<div>" + genlang(12, true,'dmraid') + ":" + String.fromCharCode(160) + name + "<br/>";
+                html += '<table style="width:100%;"><tbody><tr><td style="width:44%;"><div class="progress">' +
+                        '<div class="progress-bar progress-bar-info" style="width:' + percent + '%;"></div>' +
+                        '</div><div class="percent">' + percent + '%</div></td><td></td></tr></tbody></table>';
+                html += "</div>";
+            }
+        }
+        return html;
+    }
+
     function raid_diskicon(data) {
         var html = "";
         var img = "", alt = "";
@@ -54,17 +70,25 @@ function renderPlugin_dmraid(data) {
                         html += raid_diskicon(diskitems[j]["@attributes"]);
                     }
 
-                    html += "</td></tr><tr><td>";
+                    html += "</td></tr>";
+                    if (dmitems[i]['Action'] !== undefined) {
+                        var buildedaction = raid_buildaction(dmitems[i]['Action']['@attributes']);
+                        if (buildedaction) {
+                            html += "<tr><td>" + buildedaction + "</td></tr>";
+                        }
+                    }
+
+                    html += "<tr><td>";
                     html += "<table id=\"dmraid-" + i + "\"class=\"table table-hover table-condensed\"><tbody>";
                     html += "<tr class=\"treegrid-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">" + dmitems[i]["@attributes"]["Device_Name"] + "</span></td><td></td></tr>";
                     html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(4, true, 'dmraid')+"</span></td><td>" + dmitems[i]["@attributes"]["Name"] + "</td></tr>";  		// Name
                     html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(5, true, 'dmraid')+"</span></td><td>" + dmitems[i]["@attributes"]["Disk_Status"] + "</td></tr>"; 	// Status
                     html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(6, true, 'dmraid')+"</span></td><td>" + dmitems[i]["@attributes"]["Type"] + "</td></tr>"; 			// RAID-Type
                     html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(7, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Size"]) + "</td></tr>";// Size
-                    html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(8, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Stride"]) + "</td></tr>"; // Stride
-                    html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(9, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Subsets"]) + "</td></tr>"; // Subsets
+                    if (!isNaN(parseInt(dmitems[i]["@attributes"]["Stride"]))) html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(8, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Stride"]) + "</td></tr>"; // Stride
+                    if (!isNaN(parseInt(dmitems[i]["@attributes"]["Subsets"]))) html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(9, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Subsets"]) + "</td></tr>"; // Subsets
                     html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(10, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Devs"]) + "</td></tr>";  	// Devices
-                    html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(11, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Spares"]) + "</td></tr>";	// Spares
+                    if (!isNaN(parseInt(dmitems[i]["@attributes"]["Spares"]))) html += "<tr class=\"treegrid-parent-dmraid-" + i + "\"><td><span class=\"treegrid-spanbold\">"+genlang(11, true, 'dmraid')+"</span></td><td>" + parseInt(dmitems[i]["@attributes"]["Spares"]) + "</td></tr>";	// Spares
                     html += "</tbody></table>";
                     html += "</td></tr>";
                     html += "</tbody></table>";
