@@ -8,7 +8,7 @@
  * @package   PSI_Plugin_MDStatus
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.mdstatus.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -24,7 +24,7 @@
  * @package   PSI_Plugin_MDStatus
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -140,14 +140,66 @@ class MDStatus extends PSI_Plugin
                 } else {
                     $this->_result['devices'][$dev]['algorithm'] = -1;
                 }
-                if (preg_match('/(\[[0-9]?\/[0-9]\])/', $optionline, $res)) {
-                    $slashpos = strpos($res[0], '/');
-                    $this->_result['devices'][$dev]['registered'] = substr($res[0], 1, $slashpos - 1);
-                    $this->_result['devices'][$dev]['active'] = substr($res[0], $slashpos + 1, strlen($res[0]) - $slashpos - 2);
+                if (preg_match('/\[([0-9]+)\/([0-9]+)\]/', $optionline, $res)) {
+                    $this->_result['devices'][$dev]['registered'] = $res[1];
+                    $this->_result['devices'][$dev]['active'] = $res[2];
                 } else {
                     $this->_result['devices'][$dev]['registered'] = -1;
                     $this->_result['devices'][$dev]['active'] = -1;
                 }
+                if (isset($this->_result['devices'][$dev]['partitions'])) {
+                    asort($this->_result['devices'][$dev]['partitions']);
+                }
+                if (($this->_result['devices'][$dev]['registered']<24) && preg_match('/\[([_U]+)\]/', $optionline, $res) && (($reslen=strlen($res[1])) > 0)) {
+                    $notsparecount = 0;
+                    foreach ($this->_result['devices'][$dev]['partitions'] as $diskkey=>$disk) {
+                        if ($this->_result['devices'][$dev]['partitions'][$diskkey]['status']!=="S") {
+                            $notsparecount++;
+                        }
+                    }
+                    if ($notsparecount == $reslen) {
+                        $partnr = 0;
+                        foreach ($this->_result['devices'][$dev]['partitions'] as $diskkey=>$disk) {
+                            if ($this->_result['devices'][$dev]['partitions'][$diskkey]['status']!=="S") {
+                                if (($res[1][$partnr]=='_') && ($this->_result['devices'][$dev]['partitions'][$diskkey]['status']=="ok")) {
+                                    $this->_result['devices'][$dev]['partitions'][$diskkey]['status']="W";
+                                }
+                                $partnr++;
+                            }
+                        }
+                    } elseif ($reslen-$notsparecount == 1) {
+                        $partnr = 0;
+                        foreach ($this->_result['devices'][$dev]['partitions'] as $diskkey=>$disk) {
+                            if ($this->_result['devices'][$dev]['partitions'][$diskkey]['status']!=="S") {
+                                if ($res[1][$partnr]=='_') {
+                                    $this->_result['devices'][$dev]['partitions']["none"]['raid_index']=$this->_result['devices'][$dev]['partitions'][$diskkey]['raid_index']-1;
+                                    $this->_result['devices'][$dev]['partitions']["none"]['status']="E";
+                                }
+                                $partnr++;
+                            }
+                        }
+                        if ($res[1][$partnr]=='_') {
+                            $this->_result['devices'][$dev]['partitions']["none"]['raid_index']=$this->_result['devices'][$dev]['partitions'][$diskkey]['raid_index']+1;
+                            $this->_result['devices'][$dev]['partitions']["none"]['status']="E";
+                        }
+                        asort($this->_result['devices'][$dev]['partitions']);
+                        foreach ($this->_result['devices'][$dev]['partitions'] as $diskkey=>$disk) {
+                            if ($diskkey=="none") {
+                                $this->_result['devices'][$dev]['partitions'][$diskkey]['raid_index']="unknown";
+                            }
+                        }
+                    } else {
+                        foreach ($this->_result['devices'][$dev]['partitions'] as $diskkey=>$disk) {
+                            if ($this->_result['devices'][$dev]['partitions'][$diskkey]['status']=="ok") {
+                                $this->_result['devices'][$dev]['partitions'][$diskkey]['status']="W";
+                            }
+                        }
+                        for ($partnr=0; $partnr<$reslen-$notsparecount; $partnr++) {
+                                $this->_result['devices'][$dev]['partitions']["none".$partnr]['raid_index']="unknown";
+                                $this->_result['devices'][$dev]['partitions']["none".$partnr]['status']="E";
+                        }
+                    }
+                }
                 if (preg_match(('/([a-z]+)( *)=( *)([0-9\.]+)%/'), $this->_filecontent[$count + 1], $res) || (preg_match(('/([a-z]+)( *)=( *)([0-9\.]+)/'), $optionline, $res))) {
                     list($this->_result['devices'][$dev]['action']['name'], $this->_result['devices'][$dev]['action']['percent']) = preg_split("/=/", str_replace("%", "", $res[0]));
                     if (preg_match(('/([a-z]*=[0-9\.]+[a-z]+)/'), $this->_filecontent[$count + 1], $res)) {
@@ -157,11 +209,6 @@ class MDStatus extends PSI_Plugin
                         $this->_result['devices'][$dev]['action']['finish_time'] = -1;
                         $this->_result['devices'][$dev]['action']['finish_unit'] = -1;
                     }
-                } else {
-                    $this->_result['devices'][$dev]['action']['name'] = -1;
-                    $this->_result['devices'][$dev]['action']['percent'] = -1;
-                    $this->_result['devices'][$dev]['action']['finish_time'] = -1;
-                    $this->_result['devices'][$dev]['action']['finish_unit'] = -1;
                 }
             } else {
                 $count++;
@@ -181,7 +228,7 @@ class MDStatus extends PSI_Plugin
     /**
      * generates the XML content for the plugin
      *
-     * @return SimpleXMLObject entire XML content for the plugin
+     * @return SimpleXMLElement entire XML content for the plugin
      */
     public function xml()
     {
@@ -212,11 +259,13 @@ class MDStatus extends PSI_Plugin
                 $dev->addAttribute("Algorithm", $device["algorithm"]);
                 $dev->addAttribute("Disks_Registered", $device["registered"]);
                 $dev->addAttribute("Disks_Active", $device["active"]);
-                $action = $dev->addChild("Action");
-                $action->addAttribute("Percent", $device['action']['percent']);
-                $action->addAttribute("Name", $device['action']['name']);
-                $action->addAttribute("Time_To_Finish", $device['action']['finish_time']);
-                $action->addAttribute("Time_Unit", $device['action']['finish_unit']);
+                if (isset($device['action'])) {
+                    $action = $dev->addChild("Action");
+                    $action->addAttribute("Percent", $device['action']['percent']);
+                    $action->addAttribute("Name", $device['action']['name']);
+                    $action->addAttribute("Time_To_Finish", $device['action']['finish_time']);
+                    $action->addAttribute("Time_Unit", $device['action']['finish_unit']);
+                }
                 $disks = $dev->addChild("Disks");
                 foreach ($device['partitions'] as $diskkey=>$disk) {
                     $disktemp = $disks->addChild("Disk");
