@@ -8,7 +8,7 @@
  * @package   PSI_Plugin_PSStatus
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.psstatus.inc.php 692 2012-09-08 17:12:08Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -25,7 +25,7 @@
  * @package   PSI_Plugin_PSStatus
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -51,20 +51,20 @@ class PSStatus extends PSI_Plugin
     public function __construct($enc)
     {
         parent::__construct(__CLASS__, $enc);
-        switch (strtolower(PSI_PLUGIN_PSSTATUS_ACCESS)) {
-        case 'command':
-            if (PSI_OS == 'WINNT') {
-                try {
-                    $objLocator = new COM("WbemScripting.SWbemLocator");
-                    $wmi = $objLocator->ConnectServer();
-                    $process_wmi = $wmi->InstancesOf('Win32_Process');
-                    foreach ($process_wmi as $process) {
-                        $this->_filecontent[] = array(strtolower(trim($process->Caption)), trim($process->ProcessId));
+        if (defined('PSI_PLUGIN_PSSTATUS_PROCESSES') && is_string(PSI_PLUGIN_PSSTATUS_PROCESSES)) {
+            switch (strtolower(PSI_PLUGIN_PSSTATUS_ACCESS)) {
+            case 'command':
+                if (PSI_OS == 'WINNT') {
+                    try {
+                        $objLocator = new COM('WbemScripting.SWbemLocator');
+                        $wmi = $objLocator->ConnectServer('', 'root\CIMv2');
+                        $process_wmi = CommonFunctions::getWMI($wmi, 'Win32_Process', array('Caption', 'ProcessId'));
+                        foreach ($process_wmi as $process) {
+                            $this->_filecontent[] = array(strtolower(trim($process['Caption'])), trim($process['ProcessId']));
+                        }
+                    } catch (Exception $e) {
                     }
-                } catch (Exception $e) {
-                }
-            } else {
-                if (defined('PSI_PLUGIN_PSSTATUS_PROCESSES') && is_string(PSI_PLUGIN_PSSTATUS_PROCESSES)) {
+                } else {
                     if (preg_match(ARRAY_EXP, PSI_PLUGIN_PSSTATUS_PROCESSES)) {
                         $processes = eval(PSI_PLUGIN_PSSTATUS_PROCESSES);
                     } else {
@@ -72,35 +72,35 @@ class PSStatus extends PSI_Plugin
                     }
                     if (defined('PSI_PLUGIN_PSSTATUS_USE_REGEX') && PSI_PLUGIN_PSSTATUS_USE_REGEX === true) {
                         foreach ($processes as $process) {
-                            CommonFunctions::executeProgram("pgrep", "-n -x ".$process, $buffer, PSI_DEBUG);
+                            CommonFunctions::executeProgram("pgrep", "-n -x \"".$process."\"", $buffer, PSI_DEBUG);
                             if (strlen($buffer) > 0) {
                                 $this->_filecontent[] = array($process, $buffer);
                             }
                         }
                     } else {
                         foreach ($processes as $process) {
-                            CommonFunctions::executeProgram("pidof", "-s ".$process, $buffer, PSI_DEBUG);
+                            CommonFunctions::executeProgram("pidof", "-s -x \"".$process."\"", $buffer, PSI_DEBUG);
                             if (strlen($buffer) > 0) {
                                 $this->_filecontent[] = array($process, $buffer);
                             }
                         }
                     }
                 }
-            }
-            break;
-        case 'data':
-            CommonFunctions::rfts(APP_ROOT."/data/psstatus.txt", $buffer);
-            $processes = preg_split("/\n/", $buffer, -1, PREG_SPLIT_NO_EMPTY);
-            foreach ($processes as $process) {
-                $ps = preg_split("/[\s]?\|[\s]?/", $process, -1, PREG_SPLIT_NO_EMPTY);
-                if (count($ps) == 2) {
-                    $this->_filecontent[] = array(trim($ps[0]), trim($ps[1]));
+                break;
+            case 'data':
+                CommonFunctions::rfts(APP_ROOT."/data/psstatus.txt", $buffer);
+                $processes = preg_split("/\n/", $buffer, -1, PREG_SPLIT_NO_EMPTY);
+                foreach ($processes as $process) {
+                    $ps = preg_split("/[\s]?\|[\s]?/", $process, -1, PREG_SPLIT_NO_EMPTY);
+                    if (count($ps) == 2) {
+                        $this->_filecontent[] = array(trim($ps[0]), trim($ps[1]));
+                    }
                 }
+                break;
+            default:
+                $this->global_error->addError("switch(PSI_PLUGIN_PSSTATUS_ACCESS)", "Bad psstatus configuration in phpsysinfo.ini");
+                break;
             }
-            break;
-        default:
-            $this->global_error->addError("switch(PSI_PLUGIN_PSSTATUS_ACCESS)", "Bad psstatus configuration in phpsysinfo.ini");
-            break;
         }
     }
 
@@ -113,9 +113,6 @@ class PSStatus extends PSI_Plugin
      */
     public function execute()
     {
-        if (empty($this->_filecontent)) {
-            return;
-        }
         if (defined('PSI_PLUGIN_PSSTATUS_PROCESSES') && is_string(PSI_PLUGIN_PSSTATUS_PROCESSES)) {
             if (preg_match(ARRAY_EXP, PSI_PLUGIN_PSSTATUS_PROCESSES)) {
                 $processes = eval(PSI_PLUGIN_PSSTATUS_PROCESSES);
@@ -124,19 +121,11 @@ class PSStatus extends PSI_Plugin
             }
             if ((PSI_OS == 'WINNT') && (strtolower(PSI_PLUGIN_PSSTATUS_ACCESS) == 'command')) {
                 foreach ($processes as $process) {
-                    if ($this->_recursiveinarray(strtolower($process), $this->_filecontent)) {
-                        $this->_result[] = array($process, true);
-                    } else {
-                        $this->_result[] = array($process, false);
-                    }
+                    $this->_result[] = array($process, $this->process_inarray(strtolower($process), $this->_filecontent));
                 }
             } else {
                 foreach ($processes as $process) {
-                    if ($this->_recursiveinarray($process, $this->_filecontent)) {
-                        $this->_result[] = array($process, true);
-                    } else {
-                        $this->_result[] = array($process, false);
-                    }
+                    $this->_result[] = array($process, $this->process_inarray($process, $this->_filecontent));
                 }
             }
         }
@@ -159,17 +148,17 @@ class PSStatus extends PSI_Plugin
     }
 
     /**
-     * checks an array recursive if an value is in, extended version of in_array()
+     * checks an array if process name is in
      *
      * @param mixed $needle   what to find
      * @param array $haystack where to find
      *
      * @return boolean true - found<br>false - not found
      */
-    private function _recursiveinarray($needle, $haystack)
+    private function process_inarray($needle, $haystack)
     {
         foreach ($haystack as $stalk) {
-            if ($needle == $stalk || (is_array($stalk) && $this->_recursiveinarray($needle, $stalk))) {
+            if ($needle === $stalk[0]) {
                 return true;
             }
         }
