@@ -8,7 +8,7 @@
  * @package   PSI_Plugin_SMART
  * @author    Antoine Bertin <diaoulael@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   SVN: $Id: class.smart.inc.php 707 2012-11-28 10:20:49Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -19,7 +19,7 @@
  * @package   PSI_Plugin_SMART
  * @author    Antoine Bertin <diaoulael@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
+ * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
  */
@@ -52,45 +52,8 @@ class SMART extends PSI_Plugin
     {
         parent::__construct(__CLASS__, $enc);
         switch (strtolower(PSI_PLUGIN_SMART_ACCESS)) {
+            case 'wmi':
             case 'command':
-                if (defined('PSI_PLUGIN_SMART_DEVICES') && is_string(PSI_PLUGIN_SMART_DEVICES)) {
-                    if (preg_match(ARRAY_EXP, PSI_PLUGIN_SMART_DEVICES)) {
-                        $disks = eval(PSI_PLUGIN_SMART_DEVICES);
-                    } else {
-                        $disks = array(PSI_PLUGIN_SMART_DEVICES);
-                    }
-                    foreach ($disks as $disk) {
-                        if (trim($disk) != "") {
-                            $diskdev = "";
-                            if (preg_match("/\s*\(([^\(\(]*)\)\s*(.*)/", $disk, $devdisk)) {
-                                $diskname = trim($devdisk[2]);
-                                if (trim($devdisk[1]) != "") {
-                                    $diskdev = "--device ".preg_replace('/\./', ',', trim($devdisk[1]));
-                                }
-                            } else {
-                                $diskname = trim($disk);
-                            }
-                            $buffer = "";
-                            if (trim($diskname != "") && (CommonFunctions::executeProgram('smartctl', '--all'.' '.$diskdev.' '.$diskname, $buffer, PSI_DEBUG))) {
-                                $this->_filecontent[trim($disk)] = $buffer;
-                            }
-                        }
-                    }
-                }
-                if (defined('PSI_PLUGIN_SMART_IDS') && is_string(PSI_PLUGIN_SMART_IDS)) {
-                    if (preg_match(ARRAY_EXP, PSI_PLUGIN_SMART_IDS)) {
-                        $fullIds = eval(PSI_PLUGIN_SMART_IDS);
-                    } else {
-                        $fullIds = array(PSI_PLUGIN_SMART_IDS);
-                    }
-                    foreach ($fullIds as $fullId) {
-                        $arrFullId = preg_split('/-/', $fullId);
-                        $this->_ids[intval($arrFullId[0])] = strtolower($arrFullId[1]);
-                        if (!empty($arrFullId[2]))
-                            $this->_ids[intval($arrFullId[2])] = "#replace-".intval($arrFullId[0]);
-                    }
-                }
-                break;
             case 'data':
                 if (defined('PSI_PLUGIN_SMART_DEVICES') && is_string(PSI_PLUGIN_SMART_DEVICES)) {
                     if (preg_match(ARRAY_EXP, PSI_PLUGIN_SMART_DEVICES)) {
@@ -98,26 +61,18 @@ class SMART extends PSI_Plugin
                     } else {
                         $disks = array(PSI_PLUGIN_SMART_DEVICES);
                     }
-                    $dn=0;
-                    foreach ($disks as $disk) {
-                        $buffer="";
-                        if (CommonFunctions::rfts(APP_ROOT."/data/smart{$dn}.txt", $buffer) && !empty($buffer)) {
-                            $this->_filecontent[$disk] = $buffer;
+                    if (defined('PSI_PLUGIN_SMART_IDS') && is_string(PSI_PLUGIN_SMART_IDS)) {
+                        if (preg_match(ARRAY_EXP, PSI_PLUGIN_SMART_IDS)) {
+                            $fullIds = eval(PSI_PLUGIN_SMART_IDS);
+                        } else {
+                            $fullIds = array(PSI_PLUGIN_SMART_IDS);
+                        }
+                        foreach ($fullIds as $fullId) {
+                            $arrFullId = preg_split('/-/', $fullId);
+                            $this->_ids[intval($arrFullId[0])] = strtolower($arrFullId[1]);
+                            if (!empty($arrFullId[2]))
+                                $this->_ids[intval($arrFullId[2])] = "#replace-".intval($arrFullId[0]);
                         }
-                        $dn++;
-                    }
-                }
-                if (defined('PSI_PLUGIN_SMART_IDS') && is_string(PSI_PLUGIN_SMART_IDS)) {
-                    if (preg_match(ARRAY_EXP, PSI_PLUGIN_SMART_IDS)) {
-                        $fullIds = eval(PSI_PLUGIN_SMART_IDS);
-                    } else {
-                        $fullIds = array(PSI_PLUGIN_SMART_IDS);
-                    }
-                    foreach ($fullIds as $fullId) {
-                        $arrFullId = preg_split('/-/', $fullId);
-                        $this->_ids[intval($arrFullId[0])] = strtolower($arrFullId[1]);
-                        if (!empty($arrFullId[2]))
-                            $this->_ids[intval($arrFullId[2])] = "#replace-".intval($arrFullId[0]);
                     }
                 }
                 break;
@@ -125,6 +80,90 @@ class SMART extends PSI_Plugin
                 $this->global_error->addError("switch(PSI_PLUGIN_SMART_ACCESS)", "Bad SMART configuration in phpsysinfo.ini");
                 break;
         }
+
+        switch (strtolower(PSI_PLUGIN_SMART_ACCESS)) {
+            case 'wmi':
+                if (PSI_OS == 'WINNT') {
+                    $asd_wmi = null;
+                    try {
+                        $objLocator = new COM('WbemScripting.SWbemLocator');
+                        $wmi = $objLocator->ConnectServer('', 'root\wmi');
+                        $asd_wmi = CommonFunctions::getWMI($wmi, 'MSStorageDriver_ATAPISmartData', array('VendorSpecific'));
+                    } catch (Exception $e) {
+                    }
+                    //var_dump($asd_wmi);
+                    foreach ($asd_wmi as $_nr=>$asd) {
+                        $_name = "/dev/sd".chr(97+$_nr);
+                        if (array_search($_name, $disks) !== false) {
+                            $this->_filecontent[$_name] = "\nVendor Specific SMART Attributes with Thresholds\n";
+                            $this->_filecontent[$_name] .= "ID# _ATTRIBUTE_NAME_ FLAG VALUE WORST RAW_VALUE\n";
+                            $asdvs = $asd['VendorSpecific'];
+                            for ($c = 2; $c < count($asdvs); $c += 12) {
+                                //Attribute values 0x00, 0xff are invalid
+                                $id = $asdvs[$c];
+                                if (($id != 0) && ($id != 255)) {
+                                    switch ($id) {
+                                        case 3:
+                                            //raw16(avg16)
+                                            $this->_filecontent[$_name] .= $id." ID".$id." 0x".substr("0".dechex($asdvs[$c+2]),-2).substr("0".dechex($asdvs[$c+1]),-2)." ".substr("00".$asdvs[$c+3],-3)." ".substr("00".$asdvs[$c+4],-3)." ".($asdvs[$c+5]+256*$asdvs[$c+6])."\n";
+                                            break;
+                                        case 5:
+                                        case 196:
+                                            //raw16(raw16)
+                                            $this->_filecontent[$_name] .= $id." ID".$id." 0x".substr("0".dechex($asdvs[$c+2]),-2).substr("0".dechex($asdvs[$c+1]),-2)." ".substr("00".$asdvs[$c+3],-3)." ".substr("00".$asdvs[$c+4],-3)." ".($asdvs[$c+5]+256*$asdvs[$c+6])."\n";
+                                            break;
+                                        case 9:
+                                        case 240:
+                                            //raw24(raw8)
+                                            $this->_filecontent[$_name] .= $id." ID".$id." 0x".substr("0".dechex($asdvs[$c+2]),-2).substr("0".dechex($asdvs[$c+1]),-2)." ".substr("00".$asdvs[$c+3],-3)." ".substr("00".$asdvs[$c+4],-3)." ".($asdvs[$c+5]+256*$asdvs[$c+6]+65536*$asdvs[$c+7])."\n";
+                                            break;
+                                        case 190:
+                                        case 194:
+                                            //tempminmax
+                                            $this->_filecontent[$_name] .= $id." ID".$id." 0x".substr("0".dechex($asdvs[$c+2]),-2).substr("0".dechex($asdvs[$c+1]),-2)." ".substr("00".$asdvs[$c+3],-3)." ".substr("00".$asdvs[$c+4],-3)." ".($asdvs[$c+5]+256*$asdvs[$c+6])."\n";
+                                            break;
+                                        default:
+                                            //raw48
+                                            $this->_filecontent[$_name] .= $id." ID".$id." 0x".substr("0".dechex($asdvs[$c+2]),-2).substr("0".dechex($asdvs[$c+1]),-2)." ".substr("00".$asdvs[$c+3],-3)." ".substr("00".$asdvs[$c+4],-3)." ".($asdvs[$c+5]+256*$asdvs[$c+6]+65536*$asdvs[$c+7]+16777216*$asdvs[$c+8])."\n";
+                                            break;
+                                    }
+                                }
+                            }
+                            $this->_filecontent[$_name] .= "SMART Error Log Version";
+                        }
+                    }
+                }
+                break;
+            case 'command':
+                foreach ($disks as $disk) {
+                    if (trim($disk) != "") {
+                        $diskdev = "";
+                        if (preg_match("/\s*\(([^\(\(]*)\)\s*(.*)/", $disk, $devdisk)) {
+                            $diskname = trim($devdisk[2]);
+                            if (trim($devdisk[1]) != "") {
+                                $diskdev = "--device ".preg_replace('/\./', ',', trim($devdisk[1]));
+                            }
+                        } else {
+                            $diskname = trim($disk);
+                        }
+                        $buffer = "";
+                        if (trim($diskname != "") && (CommonFunctions::executeProgram('smartctl', '--all'.' '.$diskdev.' '.$diskname, $buffer, PSI_DEBUG))) {
+                            $this->_filecontent[trim($disk)] = $buffer;
+                        }
+                    }
+                }
+                break;
+            case 'data':
+                $dn=0;
+                foreach ($disks as $disk) {
+                    $buffer="";
+                    if (CommonFunctions::rfts(APP_ROOT."/data/smart{$dn}.txt", $buffer) && !empty($buffer)) {
+                        $this->_filecontent[$disk] = $buffer;
+                    }
+                    $dn++;
+                }
+                break;
+        }
     }
 
     /**
@@ -261,7 +300,7 @@ class SMART extends PSI_Plugin
     /**
      * generates the XML content for the plugin
      *
-     * @return SimpleXMLObject entire XML content for the plugin
+     * @return SimpleXMLElement entire XML content for the plugin
      */
     public function xml()
     {
@@ -285,7 +324,7 @@ class SMART extends PSI_Plugin
             foreach ($diskInfos as $lineInfos) {
                 $lineChild = $diskChild->addChild('attribute');
 
-                if (($lineInfos['id'] == 9) && ($lineInfos['attribute_name'] == "Power_On_Hours_and_Msec")) {
+                if (($lineInfos['id'] == 9) && isset($lineInfos['attribute_name']) && ($lineInfos['attribute_name'] !== "Power_On_Hours")) { //Power_On_Hours_and_Msec and Power_On_Seconds
                     $lineInfos['attribute_name'] = "Power_On_Hours";
                     $raw_value = preg_split("/h/", $lineInfos['raw_value'], -1, PREG_SPLIT_NO_EMPTY);
                     $lineInfos['raw_value'] = $raw_value[0];
