@@ -34,20 +34,31 @@ var uprecords_show = false;
 
 function uprecords_populate(xml) {
 
-    var html = "";
- 
+    var html = "", datetimeFormat = "";
+
+    $("Options", xml).each(function getByteFormat(id) {
+        datetimeFormat = $(this).attr("datetimeFormat");
+    });
+
     $("Plugins Plugin_uprecords uprecords Item", xml).each(function uprecords_getitem(idp) {
         html += "    <tr>\n";
         html += "      <td style=\"font-weight:normal\">" +  $(this).attr("hash") + "</td>\n";
         html += "      <td style=\"font-weight:normal\">" +  $(this).attr("Uptime") + "</td>\n";
         html += "      <td style=\"font-weight:normal\">" +  $(this).attr("System") + "</td>\n";
-/*        var lastboot = new Date($(this).attr("Bootup"));
+/*
+        var lastboot = new Date($(this).attr("Bootup"));
         if (typeof(lastboot.toUTCString)==="function") {
             html += "      <td style=\"font-weight:normal\">" +  lastboot.toUTCString() + "</td>\n";
         } else { //deprecated
             html += "      <td style=\"font-weight:normal\">" +  lastboot.toGMTString() + "</td>\n";
-        } */
-        html += "      <td style=\"font-weight:normal\">" +  $(this).attr("Bootup") + "</td>\n";
+        }
+*/
+        if ((datetimeFormat !== undefined) && (datetimeFormat.toLowerCase() === "locale")) {
+            var lastboot = new Date($(this).attr("Bootup"));
+            html += "      <td style=\"font-weight:normal\">" +  lastboot.toLocaleString() + "</td>\n";
+        } else {
+            html += "      <td style=\"font-weight:normal\">" +  $(this).attr("Bootup") + "</td>\n";
+        }
         html += "    </tr>\n";
         uprecords_show = true;
     });
