@@ -3,7 +3,7 @@ if (!defined('PSI_CONFIG_FILE')) {
     /**
      * phpSysInfo version
      */
-    define('PSI_VERSION', '3.2.5');
+    define('PSI_VERSION', '3.2.8');
     /**
      * phpSysInfo configuration
      */
@@ -47,7 +47,7 @@ if (!defined('PSI_CONFIG_FILE')) {
         } else {
             $allowed = array(strtolower(PSI_ALLOWED));
         }
-        
+
         if (isset($_SERVER["HTTP_X_FORWARDED_FOR"])) {
             $ip = $_SERVER["HTTP_X_FORWARDED_FOR"];
         } else {
@@ -102,22 +102,20 @@ if (!defined('PSI_CONFIG_FILE')) {
     if (!defined('PSI_OS')) { //if not overloaded in phpsysinfo.ini
         /* get Linux code page */
         if (PHP_OS == 'Linux') {
-            if (file_exists('/etc/sysconfig/i18n')) {
-                $contents = @file_get_contents('/etc/sysconfig/i18n');
-            } elseif (file_exists('/etc/default/locale')) {
-                $contents = @file_get_contents('/etc/default/locale');
-            } elseif (file_exists('/etc/locale.conf')) {
-                $contents = @file_get_contents('/etc/locale.conf');
-            } elseif (file_exists('/etc/sysconfig/language')) {
-                $contents = @file_get_contents('/etc/sysconfig/language');
-            } elseif (file_exists('/etc/profile.d/lang.sh')) {
-                $contents = @file_get_contents('/etc/profile.d/lang.sh');
-            } elseif (file_exists('/etc/profile')) {
-                $contents = @file_get_contents('/etc/profile');
+            if (file_exists($fname = '/etc/sysconfig/i18n')
+               || file_exists($fname = '/etc/default/locale')
+               || file_exists($fname = '/etc/locale.conf')
+               || file_exists($fname = '/etc/sysconfig/language')
+               || file_exists($fname = '/etc/profile.d/lang.sh')
+               || file_exists($fname = '/etc/profile')) {
+                $contents = @file_get_contents($fname);
             } else {
                 $contents = false;
                 if (file_exists('/system/build.prop')) { //Android
                     define('PSI_OS', 'Android');
+                    if (@exec('uname -o 2>/dev/null', $unameo) && (sizeof($unameo)>0) && (($unameo0 = trim($unameo[0])) != "")) {
+                        define('PSI_UNAMEO', $unameo0);
+                    }
                     if (!defined('PSI_MODE_POPEN')) { //if not overloaded in phpsysinfo.ini
                         if (!function_exists("proc_open")) { //proc_open function test by executing 'pwd' command
                             define('PSI_MODE_POPEN', true); //use popen() function - no stderr error handling
@@ -133,7 +131,7 @@ if (!defined('PSI_CONFIG_FILE')) {
                                 $w = null;
                                 $e = null;
 
-                                while (!(feof($pipes[1]) || feof($pipes[2]))) {
+                                while (!(feof($pipes[1]) && feof($pipes[2]))) {
                                     $read = array($pipes[1], $pipes[2]);
 
                                     $n = stream_select($read, $w, $e, 5);
@@ -145,8 +143,7 @@ if (!defined('PSI_CONFIG_FILE')) {
                                     foreach ($read as $r) {
                                         if ($r == $pipes[1]) {
                                             $out .= fread($r, 4096);
-                                        }
-                                        if ($r == $pipes[2]) {
+                                        } elseif (feof($pipes[1]) && ($r == $pipes[2])) {//read STDERR after STDOUT
                                             $err .= fread($r, 4096);
                                         }
                                     }
@@ -170,16 +167,21 @@ if (!defined('PSI_CONFIG_FILE')) {
                && $contents && (preg_match('/^(LANG="?[^"\n]*"?)/m', $contents, $matches)
                || preg_match('/^RC_(LANG="?[^"\n]*"?)/m', $contents, $matches)
                || preg_match('/^\s*export (LANG="?[^"\n]*"?)/m', $contents, $matches))) {
-                if (!defined('PSI_SYSTEM_CODEPAGE') && @exec($matches[1].' locale -k LC_CTYPE 2>/dev/null', $lines)) { //if not overloaded in phpsysinfo.ini
-                    foreach ($lines as $line) {
-                        if (preg_match('/^charmap="?([^"]*)/', $line, $matches2)) {
-                            define('PSI_SYSTEM_CODEPAGE', $matches2[1]);
-                            break;
+                if (!defined('PSI_SYSTEM_CODEPAGE')) {
+                    if (file_exists($vtfname = '/sys/module/vt/parameters/default_utf8')
+                       && (trim(@file_get_contents($vtfname)) === "1")) {
+                            define('PSI_SYSTEM_CODEPAGE', 'UTF-8');
+                    } elseif (@exec($matches[1].' locale -k LC_CTYPE 2>/dev/null', $lines)) { //if not overloaded in phpsysinfo.ini
+                        foreach ($lines as $line) {
+                            if (preg_match('/^charmap="?([^"]*)/', $line, $matches2)) {
+                                define('PSI_SYSTEM_CODEPAGE', $matches2[1]);
+                                break;
+                            }
                         }
                     }
                 }
-                if (!defined('PSI_SYSTEM_LANG') && @exec($matches[1].' locale 2>/dev/null', $lines)) { //also if not overloaded in phpsysinfo.ini
-                    foreach ($lines as $line) {
+                if (!defined('PSI_SYSTEM_LANG') && @exec($matches[1].' locale 2>/dev/null', $lines2)) { //also if not overloaded in phpsysinfo.ini
+                    foreach ($lines2 as $line) {
                         if (preg_match('/^LC_MESSAGES="?([^\."@]*)/', $line, $matches2)) {
                             $lang = "";
                             if (is_readable(APP_ROOT.'/data/languages.ini') && ($langdata = @parse_ini_file(APP_ROOT.'/data/languages.ini', true))) {
@@ -257,6 +259,9 @@ if (!defined('PSI_CONFIG_FILE')) {
     }
 
     if (!defined('PSI_JSON_ISSUE')) { //if not overloaded in phpsysinfo.ini
+        if (!extension_loaded("xml")) {
+            die("phpSysInfo requires the xml extension to php in order to work properly.");
+        }
         if (simplexml_load_string("<A><B><C/></B>\n</A>") !== simplexml_load_string("<A><B><C/></B></A>")) { // json_encode issue test
             define('PSI_JSON_ISSUE', true); // Problem must be solved
         }
